<?php
/*
Plugin Name: RSS Stream
Version: 0.1
Plugin URI: http://rick.jinlabs.com/code/rss-stream
Description: Displays your social feeds in a lifestream way.
Author: Ricardo Gonz&aacute;lez
Author URI: http://rick.jinlabs.com/
*/

/*  Copyright 2007  Ricardo Gonzlez Castro (rick[at]jinlabs.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


include_once(ABSPATH . WPINC . '/rss.php');
$lifestream = array();

define('MAGPIE_CACHE_AGE', 10*10);

function RSSS_URL() {
  return trailingslashit(get_settings('siteurl')) . 'wp-content/plugins/rss-stream';
}

function rss_stream_twitter($username = '', $hyperlinks = true, $twitter_users = true) {

	global $lifestream;
	
	$messages = fetch_rss('http://twitter.com/statuses/user_timeline/'.$username.'.rss');

	if ($list) echo '<ul class="twitter">';
	
	if ($username != '') {
		foreach ( $messages->items as $message ) {
			$msg = " ".substr(strstr($message['description'],': '), 2, strlen($message['description']))." ";
			$date = strtotime($message['pubdate']);
			$link = $message['link'];
		
			$lifestream[$date]['date'] = $date;	
	  		$lifestream[$date]['type'] = 'twitter';		  	
			$lifestream[$date]['link'] = $link;

            if ($hyperlinks) { $msg = hyperlinks($msg); }
            if ($twitter_users)  { $msg = twitter_users($msg); }

			$lifestream[$date]['msg'] =  $msg;
		}
	}
}

function rss_stream_delicious($username = '', $tags = false, $filtertag = '', $displaydesc = false ) {
	
	global $lifestream;
	
	$rss = 'http://del.icio.us/rss/'.$username;
	
	if($filtertag != '') { $rss .= '/'.$filtertag; }

	$bookmarks = fetch_rss($rss);

	if ($username != '') {
		foreach ( $bookmarks->items as $bookmark ) {
			$msg = $bookmark['title'];
			$date = strtotime($bookmark['dc']['date']);
			$link = $bookmark['link'];
			$desc = $bookmark['description'];
	
			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'delicious';		  	
			$lifestream[$date]['link'] = $link;
			$lifestream[$date]['msg'] = '<a href="'.$link.'" class="delicious-link">'.$msg.'</a>';
			if ($displaydesc && $desc != '') {
				$lifestream[$date]['msg'] .= '<br /><span class="delicious-desc">'.$desc.'</span>';
			}
			
			if ($tags) {
				$lifestream[$date]['msg'] .= '<br /><div class="delicious-tags">';
				$tagged = explode(' ', htmlentities($bookmark['dc']['subject'],ENT_NOQUOTES ,'UTF-8'));
				foreach ($tagged as $tag) {
	       			$lifestream[$date]['msg'] .= '<a href="http://del.icio.us/tag/'.$tag.'" class="delicious-link-tag">'.$tag.'</a> '; // Puts a link to the tag.
				}
				$lifestream[$date]['msg'] .= '</div>';
			}
	
		}
	}
}

function rss_stream_lastfm($username = '') {
	global $lifestream;

	$songs = fetch_rss('http://ws.audioscrobbler.com/1.0/user/'.$username.'/recenttracks.rss');

	if ($username != '') {
		foreach ( $songs->items as $song ) {
			$msg = $song['title'];
			$date = strtotime($song['pubdate']);
			$link = $song['link'];

			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'lastfm';		  	
			$lifestream[$date]['link'] = $link;
			
		    $lifestream[$date]['msg'] = '<a href="'.$link.'" class="lastfm-link">'.$msg.'</a>'; 

		}

	}
}

function rss_stream_blog($feed = '', $showautor = false) {
	global $lifestream;

	$blog = fetch_rss($feed);

	if ($feed != '') {
		foreach ( $blog->items as $post ) {
			$title = $post['title'];
			$date = strtotime($post['pubdate']);
			$link = $post['link'];
			$autor = $post['dc']['creator'];
			$msg = '<a href="'.$link.'" class="blog-link">'.$title.'</a>';
			if($showautor) $msg .= " by $autor";		

			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'blog';		  	
			$lifestream[$date]['link'] = $link;
			
		    $lifestream[$date]['msg'] = $msg; 

		}

	}
}

function rss_stream_flickr($userid = '') {
	
	global $lifestream;
	
	$rss = 'http://api.flickr.com/services/feeds/photos_public.gne?id=' . $userid . '&format=rss_200';

	$flickr = fetch_rss($rss);

	if ($userid != '') {
		foreach ( $flickr->items as $foto ) {
			$msg = $foto['title'];
			$date = strtotime($foto['pubdate']);
			$link = $foto['link'];
	
			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'flickr';		  	
			$lifestream[$date]['link'] = $link;
			
			$lifestream[$date]['msg'] = '<a href="'.$link.'" class="flickr-link">'.$msg.'</a>';

		}
	}
}

function rss_stream_facebook($feed = '') {
	global $lifestream;

	$facebook = fetch_rss($feed);

	if ($feed != '') {
		foreach ( $facebook->items as $status ) {
			$title = $status['title'];
			$date = strtotime($status['pubdate']);
			$link = htmlspecialchars($status['link']);
			$msg = '<a href="'.$link.'" class="facebook-link">'.$title.'</a>';

			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'facebook';		  	
			$lifestream[$date]['link'] = $link;
			
		    $lifestream[$date]['msg'] = $msg; 

		}

	}
}


function rss_stream_pownce($username = '', $reply = true, $linked = true, $diff=0) {

	global $lifestream;
	
	$messages = fetch_rss("http://pownce.com/feeds/public/$username/");
	
	if ($username != '') {
	
		foreach ( $messages->items as $message ) {
			$text = $message['summary'];
			$related = $message['link_related'];
			$event_name = $message['pownce']['event_name'];
			$event_location = $message['event_location'];
			$event_date = strtotime($diff.' hours', strtotime($message['event_date']));
			$replies = $message['pownce']['replies'];
			$replies_text = ($replies == 1) ? ' Reply' : ' Replies';
			$date = strtotime('+6 hours',strtotime($message['updated']));
			$link = $message['link'];
		
			$msg = $text;
			if ($linked) $msg = hyperlinks(' '.$msg.' ');
			if ($event_name) $msg .= ' <span class="pownce-event">(Event: ' . $event_name;
			if ($event_location && $event_name) $msg .= ' at ' . $event_location;
			if ($event_date && $event_name) $msg .= ' on ' . $event_date;
			if ($event_name) $msg .= ')</span>';
			if ($reply) $msg .= ' <span class="pownce-replies">(<a href="' . $link . '" title="' . $replies . $replies_text . '">' . $replies . '</a>)</span>';
			
			$lifestream[$date]['date'] = $date;
			$lifestream[$date]['type'] = 'pownce';		  	
			$lifestream[$date]['link'] = $link;
			
		    $lifestream[$date]['msg'] = $msg;

		}
	}
}

function RSS_Stream() {
	
	global $lifestream;
	
	if (get_option('RSS_Stream_hour')=='') update_option('RSS_Stream_hour', "g:ia");
	if (get_option('RSS_Stream_date')=='') update_option('RSS_Stream_date', "%B %e");
	 
	date_default_timezone_set(get_option('RSS_Stream_timezone'));
	setlocale(LC_TIME, get_locale());
	
	if(get_option('RSS_Stream_twitteruser')!='') { rss_stream_twitter(get_option('RSS_Stream_twitteruser'), get_option('RSS_Stream_twitterhyperlinks'), get_option('RSS_Stream_twitterreplies')); }
	if(get_option('RSS_Stream_delicioususer')!='') { rss_stream_delicious(get_option('RSS_Stream_delicioususer'), get_option('RSS_Stream_deliciousshowtags'), get_option('RSS_Stream_deliciousfiltertag'), get_option('RSS_Stream_deliciousshowdesc')); }
	if(get_option('RSS_Stream_lastfmuser')!='') { rss_stream_lastfm(get_option('RSS_Stream_lastfmuser')); }
	if(get_option('RSS_Stream_blogfeed')!='') { rss_stream_blog(get_option('RSS_Stream_blogfeed'), get_option('RSS_Stream_blogshowautor')); }
	if(get_option('RSS_Stream_flickruser')!='') { rss_stream_flickr(get_option('RSS_Stream_flickruser')); }
	if(get_option('RSS_Stream_facebookfeed')!='') { rss_stream_facebook(get_option('RSS_Stream_facebookfeed')); }
	if(get_option('RSS_Stream_pownceuser')!='') { rss_stream_pownce(get_option('RSS_Stream_pownceuser'),  get_option('RSS_Stream_pownceshowreplies'), get_option('RSS_Stream_powncelink'), get_option('RSS_Stream_powncediff')); }	
	
?>

<div id="RSS_Stream">
<table class="hcalendar RSSS_table">
<?php
krsort( $lifestream );

$day = '';
if(get_option('RSS_Stream_twitteruser')!='' || get_option('RSS_Stream_delicioususer')!='' || get_option('RSS_Stream_lastfmuser')!='' || get_option('RSS_Stream_blogfeed')!='' || get_option('RSS_Stream_flickruser')!='' || get_option('RSS_Stream_facebookfeed')!='' || get_option('RSS_Stream_pownceuser')!='') {
	foreach ( $lifestream as $timestamp => $item ) {
	    $this_day = ucfirst(htmlentities(strftime(get_option('RSS_Stream_date'),$timestamp )));
	    	if ( $day != $this_day ) {
	?>
	<tr>
	<th colspan="3">
	<h2 class="RSSS_date"><?php echo $this_day; ?></h2>
	</th>
	</tr>
	<?php $day = $this_day; } ?>
	<tr>
	<td class="RSSS_icon">
		<a href="<?php echo $item[link]; ?>" title="<?php echo $item[type]; ?>"><img src="<?php echo RSSS_URL(). '/images/'. $item["type"] . '.png'; ?>" alt="<?php echo $item["type"]; ?>" /></a>
	</td>
	<td class="RSSS_hour RSSS_<?php  echo $item["type"]; ?>">
	    	<abbr class="dtstart" title="<?php echo date("c",$timestamp); ?>"><?php echo date(get_option('RSS_Stream_hour'), $timestamp); ?></abbr>
	</td>
	<td class="RSSS_msg">
	    <?php echo $item["msg"]; ?>
	</td>
	</tr>
	<?php
	}
}
?>
</table>
<p class="RSSS_credits">By <a href="http://rick.jinlabs.com/code/rss-stream" title="RSS Stream">RSS Stream</a></p>
</div>
<?php	
}

function RSS_Stream_subpanel() {

  load_plugin_textdomain('RSS-Stream', 'wp-content/plugins/rss-stream/locales');
	date_default_timezone_set(get_option('RSS_Stream_timezone'));
	setlocale(LC_TIME, get_locale());
	   		
     if (isset($_POST['update_RSS_Stream'])) {
       $option_RSS_Stream_date = $_POST['RSS_Stream_date']; 
       $option_RSS_Stream_hour = $_POST['RSS_Stream_hour']; 
       $option_RSS_Stream_timezone = $_POST['RSS_Stream_timezone'];  
     
	   update_option('RSS_Stream_date', $option_RSS_Stream_date);
       update_option('RSS_Stream_hour', $option_RSS_Stream_hour);
       update_option('RSS_Stream_timezone', $option_RSS_Stream_timezone);

       $option_RSS_Stream_twitteruser = $_POST['RSS_Stream_twitteruser'];
       $option_RSS_Stream_twitterhyperlinks = $_POST['RSS_Stream_twitterhyperlinks'];
       $option_RSS_Stream_twitterreplies = $_POST['RSS_Stream_twitterreplies'];   	          
       update_option('RSS_Stream_twitteruser', $option_RSS_Stream_twitteruser);
       update_option('RSS_Stream_twitterhyperlinks', $option_RSS_Stream_twitterhyperlinks);
       update_option('RSS_Stream_twitterreplies', $option_RSS_Stream_twitterreplies);

       $option_RSS_Stream_delicioususer = $_POST['RSS_Stream_delicioususer'];
       $option_RSS_Stream_deliciousshowtags = $_POST['RSS_Stream_deliciousshowtags'];
       $option_RSS_Stream_deliciousfiltertag = $_POST['RSS_Stream_deliciousfiltertag'];
       $option_RSS_Stream_deliciousshowdesc = $_POST['RSS_Stream_deliciousshowdesc'];   	          
       update_option('RSS_Stream_delicioususer', $option_RSS_Stream_delicioususer);
       update_option('RSS_Stream_deliciousshowtags', $option_RSS_Stream_deliciousshowtags);
       update_option('RSS_Stream_deliciousfiltertag', $option_RSS_Stream_deliciousfiltertag);
       update_option('RSS_Stream_deliciousshowdesc', $option_RSS_Stream_deliciousshowdesc);

       $option_RSS_Stream_lastfmuser = $_POST['RSS_Stream_lastfmuser'];         
       update_option('RSS_Stream_lastfmuser', $option_RSS_Stream_lastfmuser);

       $option_RSS_Stream_flickruser = $_POST['RSS_Stream_flickruser'];         
       update_option('RSS_Stream_flickruser', $option_RSS_Stream_flickruser);

       $option_RSS_Stream_blogfeed = $_POST['RSS_Stream_blogfeed'];         
       $option_RSS_Stream_blogshowautor = $_POST['RSS_Stream_blogshowautor'];         
       update_option('RSS_Stream_blogfeed', $option_RSS_Stream_blogfeed);
       update_option('RSS_Stream_blogshowautor', $option_RSS_Stream_blogshowautor);

       $option_RSS_Stream_facebookfeed = $_POST['RSS_Stream_facebookfeed'];         
       update_option('RSS_Stream_facebookfeed', $option_RSS_Stream_facebookfeed);

       $option_RSS_Stream_pownceuser = $_POST['RSS_Stream_pownceuser'];         
       $option_RSS_Stream_powncelink = $_POST['RSS_Stream_powncelink'];
       $option_RSS_Stream_pownceshowreplies = $_POST['RSS_Stream_pownceshowreplies'];         
       $option_RSS_Stream_powncediff = $_POST['RSS_Stream_powncediff'];         
       update_option('RSS_Stream_powncediff', $option_RSS_Stream_powncediff);
       update_option('RSS_Stream_pownceuser', $option_RSS_Stream_pownceuser);	      
       update_option('RSS_Stream_powncelink', $option_RSS_Stream_powncelink);
       update_option('RSS_Stream_pownceshowreplies', $option_RSS_Stream_pownceshowreplies);
       ?> <div class="updated"><p>RSS Stream options changes saved.</p></div> <?php
     }

	?>
	
	<div class="wrap">
		<h2><?PHP _e('RSS Stream Options', 'RSS-Stream'); ?></h2>
		<form method="post">
				<p><div class="submit"><input type="submit" name="update_RSS_Stream" id="update_RSS_Stream" value="<?php _e('Update RSS Stream Options', 'RSS-Stream') ?>"  style="font-weight:bold;" /></div></p>
		
		<fieldset class="options">
		<legend><?PHP _e("General Options", 'RSS-Stream'); ?></legend>
		<table>
		 <tr>
		  <td><p><strong><label for="RSS_Stream_date"><?PHP _e("Date format", 'RSS-Stream'); ?></label>:</strong></p></td>
	    <td><input name="RSS_Stream_date" type="text" id="RSS_Stream_date" value="<?php echo get_option('RSS_Stream_date'); ?>" size="20" />
        		PHP <a href="http://es.php.net/strftime">strftime()</a> sintax. Ex. <?php  echo htmlentities(strftime(get_option('RSS_Stream_date'))); ?></p>
      </td>
     </tr>
		 <tr>
		  <td><p><strong><label for="RSS_Stream_hour"><?PHP _e("Hour format", 'RSS-Stream'); ?></label>:</strong></p></td>
	    <td><input name="RSS_Stream_hour" type="text" id="RSS_Stream_hour" value="<?php echo get_option('RSS_Stream_hour'); ?>" size="20" />
        		PHP <a href="http://es.php.net/date">date()</a> sintax. Ex. <?php  echo date(get_option('RSS_Stream_hour')); ?></p>
      </td>
     </tr>
         <tr>
          <td><p><strong><?PHP _e("Timezone", 'RSS-Stream'); ?>:</strong></p></td>
          <td>
        	<select name="RSS_Stream_timezone" id="RSS_Stream_timezone">
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-9') { echo 'selected'; } ?> value="Etc/GMT-9">GMT +9</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-8') { echo 'selected'; } ?> value="Etc/GMT-8">GMT +8</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-7') { echo 'selected'; } ?> value="Etc/GMT-7">GMT +7</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-6') { echo 'selected'; } ?> value="Etc/GMT-6">GMT +6</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-5') { echo 'selected'; } ?> value="Etc/GMT-5">GMT +5</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-4') { echo 'selected'; } ?> value="Etc/GMT-4">GMT +4</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-3') { echo 'selected'; } ?> value="Etc/GMT-3">GMT +3</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-2') { echo 'selected'; } ?> value="Etc/GMT-2">GMT +2</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT-1') { echo 'selected'; } ?> value="Etc/GMT-1">GMT +1</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT0') { echo 'selected'; } ?> value="Etc/GMT0">GMT</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+1') { echo 'selected'; } ?> value="Etc/GMT+1">GMT -1</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+2') { echo 'selected'; } ?> value="Etc/GMT+2">GMT -2</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+3') { echo 'selected'; } ?> value="Etc/GMT+3">GMT -3</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+4') { echo 'selected'; } ?> value="Etc/GMT+4">GMT -4</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+5') { echo 'selected'; } ?> value="Etc/GMT+5">GMT -5</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+6') { echo 'selected'; } ?> value="Etc/GMT+6">GMT -6</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+7') { echo 'selected'; } ?> value="Etc/GMT+7">GMT -7</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+8') { echo 'selected'; } ?> value="Etc/GMT+8">GMT -8</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+9') { echo 'selected'; } ?> value="Etc/GMT+9">GMT -9</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+10') { echo 'selected'; } ?> value="Etc/GMT+10">GMT -10</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+11') { echo 'selected'; } ?> value="Etc/GMT+11">GMT -11</option>
            <option <?php if(get_option('RSS_Stream_timezone') == 'Etc/GMT+12') { echo 'selected'; } ?> value="Etc/GMT+12">GMT -12</option>

                            
		      </select>
           </td> 
         </tr>


         </table>

        </fieldset>
		    
		<fieldset class="options"> 
        <legend>Twitter</legend>

        <fieldset class="options">
          <table>
               <tr>
                <td><p><strong><label for="RSS_Stream_twitteruser"><?PHP _e("User", 'RSS-Stream'); ?></label></strong></p></td>
                <td><p><input name="RSS_Stream_twitteruser" type="text" id="RSS_Stream_twitteruser" value="<?php echo get_option('RSS_Stream_twitteruser'); ?>" size="25" /></p></td>
               </tr>
           <tr>
            <td><p><input name="RSS_Stream_twitterhyperlinks" type="checkbox" id="RSS_Stream_twitterhyperlinks" value="true" <?php if(get_option('RSS_Stream_twitterhyperlinks') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_twitterhyperlinks"><strong><?PHP _e("Discover hyperlinks", 'RSS-Stream'); ?></strong></label></p></td>
           </tr>
           <tr>
            <td><p><input name="RSS_Stream_twitterreplies" type="checkbox" id="RSS_Stream_twitterreplies" value="true" <?php if(get_option('RSS_Stream_twitterreplies') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_twitterreplies"><strong><?PHP _e("Discover @replies", 'RSS-Stream'); ?></strong></label></p></td>
           </tr>		 
              </table>
        </fieldset>

    </fieldset>
    
		<fieldset class="options"> 
        <legend>del.icio.us</legend>

        <fieldset class="options">
          <table>
               <tr>
                <td><p><strong><label for="RSS_Stream_delicioususer"><?PHP _e("User", 'RSS-Stream'); ?>:</label></strong></p></td>
                <td><p><input name="RSS_Stream_delicioususer" type="text" id="RSS_Stream_delicioususer" value="<?php echo get_option('RSS_Stream_delicioususer'); ?>" size="25" /></p></td>
               </tr>
           <tr>
            <td><p><input name="RSS_Stream_deliciousshowtags" type="checkbox" id="RSS_Stream_deliciousshowtags" value="true" <?php if(get_option('RSS_Stream_deliciousshowtags') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_deliciousshowtags"><strong><?PHP _e("Show tags", 'RSS-Stream'); ?></strong></label></p></td>
           </tr>	         
               <tr>
                <td><p><strong><label for="RSS_Stream_deliciousfiltertag"><?PHP _e("Filter tag(s)", 'RSS-Stream'); ?>:</label></strong></td>
                <td><input name="RSS_Stream_deliciousfiltertag" type="text" id="RSS_Stream_deliciousfiltertag" value="<?php echo get_option('RSS_Stream_deliciousfiltertag'); ?>" size="10" /> <em>i.e. cat+dog+fish</em></p></td>
               </tr>
           <tr>
            <td><p><input name="RSS_Stream_deliciousshowdesc" type="checkbox" id="RSS_Stream_deliciousshowdesc" value="true" <?php if(get_option('RSS_Stream_deliciousshowdesc') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_deliciousshowdesc"><strong><?PHP _e("Show bookmark's descriptions", 'RSS-Stream'); ?></strong></label></p></td>
           </tr>	 
              </table>
        </fieldset>

    </fieldset>    

		<fieldset class="options"> 
        <legend>Last.fm</legend>


        <fieldset class="options">
		<table>
         <tr>
          <td><p><strong><label for="RSS_Stream_lastfmuser"><?PHP _e("User", 'RSS-Stream'); ?>:</label></strong></p></td>
          <td><input name="RSS_Stream_lastfmuser" type="text" id="RSS_Stream_lastfmuser" value="<?php echo get_option('RSS_Stream_lastfmuser'); ?>" size="25" /></p>
         </tr>
        </table>
        </fieldset>

    </fieldset>   

		<fieldset class="options"> 
        <legend>flickr</legend>


        <fieldset class="options">
		<table>
         <tr>
          <td><p><strong><label for="RSS_Stream_flickruser"><?PHP _e("ID", 'RSS-Stream'); ?>:</label></strong></p></td>
          <td><p><input name="RSS_Stream_flickruser" type="text" id="RSS_Stream_flickruser" value="<?php echo get_option('RSS_Stream_flickruser'); ?>" size="25" /> <?PHP _e('Use <a href="http://idgettr.com">idGettr</a> to find your id.', 'RSS-Stream'); ?></p></td>
         </tr>
        </table>
        </fieldset>

    </fieldset>   	    

	<fieldset class="options"> 
        <legend>Facebook</legend>


        <fieldset class="options">
		<table>
         <tr>
          <td><p><strong><label for="RSS_Stream_facebookfeed"><?PHP _e("Feed", 'RSS-Stream'); ?>:</label></strong></p></td>
          <td><p><input name="RSS_Stream_facebookfeed" type="text" id="RSS_Stream_facebookfeed" value="<?php echo get_option('RSS_Stream_facebookfeed'); ?>" size="75" /></p></td>
         </tr>   
        </table>
        </fieldset>

    </fieldset> 

		<fieldset class="options"> 
        <legend>Pownce</legend>


        <fieldset class="options">
		<table>
         <tr>
          <td><p><strong><label for="RSS_Stream_pownceuser"><?PHP _e("User", 'RSS-Stream'); ?>:</label></strong></p></td>
          <td><p><input name="RSS_Stream_pownceuser" type="text" id="RSS_Stream_pownceuser" value="<?php echo get_option('RSS_Stream_pownceuser'); ?>" size="25" /></p></td>
         </tr>
		 <tr>
		  <td><p><input name="RSS_Stream_powncelink" type="checkbox" id="RSS_Stream_powncelink" value="true" <?php if(get_option('RSS_Stream_powncelink') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_powncelink"><strong><?PHP _e("Discover hyperlinks", 'RSS-Stream'); ?></strong></label></p></td>
		 </tr>         
		 <tr>
		  <td><p><input name="RSS_Stream_pownceshowreplies" type="checkbox" id="RSS_Stream_pownceshowreplies" value="true" <?php if(get_option('RSS_Stream_pownceshowreplies') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_pownceshowreplies"><strong><?PHP _e("Show replies", 'RSS-Stream'); ?></strong></label></p></td>
		 </tr>
		 
		<tr>
          <td><p><strong><?PHP _e("Time diff", 'RSS-Stream'); ?></strong></p></td>
          <td>
        	<select name="RSS_Stream_powncediff" id="RSS_Stream_powncediff">
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-9') { echo 'selected'; } ?> value="-9">+9</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-8') { echo 'selected'; } ?> value="-8">+8</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-7') { echo 'selected'; } ?> value="-7">+7</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-6') { echo 'selected'; } ?> value="-6">+6</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-5') { echo 'selected'; } ?> value="-5">+5</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-4') { echo 'selected'; } ?> value="-4">+4</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-3') { echo 'selected'; } ?> value="-3">+3</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-2') { echo 'selected'; } ?> value="-2">+2</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '-1') { echo 'selected'; } ?> value="-1">+1</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '0') { echo 'selected'; } ?> value="0">0</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+1') { echo 'selected'; } ?> value="+1">-1</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+2') { echo 'selected'; } ?> value="+2">-2</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+3') { echo 'selected'; } ?> value="+3">-3</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+4') { echo 'selected'; } ?> value="+4">-4</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+5') { echo 'selected'; } ?> value="+5">-5</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+6') { echo 'selected'; } ?> value="+6">-6</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+7') { echo 'selected'; } ?> value="+7">-7</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+8') { echo 'selected'; } ?> value="+8">-8</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+9') { echo 'selected'; } ?> value="+9">-9</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+10') { echo 'selected'; } ?> value="+10">-10</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+11') { echo 'selected'; } ?> value="+11">-11</option>
	            <option <?php if(get_option('RSS_Stream_powncediff') == '+12') { echo 'selected'; } ?> value="+12">-12</option>                        
		    </select> <?PHP _e("Hours", 'RSS-Stream'); ?>
           </td> 
         </tr>
		 
		  
        </table>
        </fieldset>

    </fieldset> 

		<fieldset class="options"> 
        <legend>Blog</legend>


        <fieldset class="options">
		<table>
         <tr>
          <td><p><strong><label for="RSS_Stream_blogfeed"><?PHP _e("Feed", 'RSS-Stream'); ?>:</label></strong></p></td>
          <td><p><input name="RSS_Stream_blogfeed" type="text" id="RSS_Stream_blogfeed" value="<?php echo get_option('RSS_Stream_blogfeed'); ?>" size="75" /></p></td>
         </tr>
		 <tr>
		  <td><p><input name="RSS_Stream_blogshowautor" type="checkbox" id="RSS_Stream_blogshowautor" value="true" <?php if(get_option('RSS_Stream_blogshowautor') == 'true') { echo 'checked="checked"'; } ?> />  <label for="RSS_Stream_blogshowautor"><strong><?PHP _e("Show post autor", 'RSS-Stream'); ?></strong></label></p></td>
		 </tr>         
        </table>
        </fieldset>

    </fieldset> 
	    
		<p><div class="submit"><input type="submit" name="update_RSS_Stream" id="update_RSS_Stream" value="<?php _e('Update RSS Stream Options', 'RSS-Stream') ?>"  style="font-weight:bold;" /></div></p>
    </form>  
    </div>

<?php } // end flickrRSS_subpanel()

function RSSS_admin_menu() {
   if (function_exists('add_options_page')) {
        add_options_page('RSS Stream Options Page', 'RSS Stream', 8, basename(__FILE__), 'RSS_Stream_subpanel');
        }
}

function RSS_Stream_header() {
  
  	echo '<link rel="stylesheet" type="text/css" media="screen" href="'.RSSS_URL().'/rss-stream.css" />';
}

add_action('admin_menu', 'RSSS_admin_menu');

add_action('wp_head', 'RSS_Stream_header');
  
register_activation_hook( __FILE__, 'RSS_Stream_Init');

function RSS_Stream_Init(){
	add_option("RSS_Stream_date", "%B %e");
	add_option("RSS_Stream_hour", "g:ia");
	add_option("RSS_Stream_blogfeed", bloginfo('rss2_url'));
}